      <!-- Include Dropzone and moment -->
      <link rel="stylesheet" href="ui/dropzone/dist/min/dropzone.min.css">
      <script src="ui/dropzone/dist/min/dropzone.min.js"></script>
      <script src="ui/moment/min/moment-with-locales.min.js"></script>
      <div class="filemanager" data-src="drive"></div>
      <script>
        Dropzone.autodiscover = false
        $('.filemanager').filemanager({
          pageSize: 4,
          data: ...,
          columns: [
            {name: "foo"},
            {name: "bar"}
          ]
          // FormHandler options
        })
      </script>